@@ -34,16 +34,18 @@ def create_ticket_rql(title, pname):
            {'title': unicode(title), 'name': unicode(pname)}
 
 
-def security_tc_init_project(tc, name, user_prefix=None):
-    req = tc.request()
-    project = req.execute(*create_project_rql(name)).get_entity(0, 0)
+# XXX take both TestCase *class* and session (need for both since session only
+# available on TestCase *instance*)
+def security_tc_init_project(tc, session, name, user_prefix=None):
+    project = session.execute(*create_project_rql(name)).get_entity(0, 0)
     if user_prefix is None:
         user_prefix = name
     for perm in (u'developer', u'client'):
         group = "%s%ss" % (name, perm)
-        req.create_entity('CWGroup', name=group)
-        tc.grant_permission(tc.session, project, group, perm)
-        tc.create_user(req, '%s%s' % (user_prefix, perm), groups=('users', group,))
+        session.create_entity('CWGroup', name=group)
+        tc.grant_permission(session, project, group, perm)
+        tc.create_user(session, '%s%s' % (user_prefix, perm), groups=('users', group,),
+                       commit=False)
     return project
 
 
@@ -68,6 +70,11 @@ class TrackerBaseTC(TrackerTCMixIn, CubicWebTC):
         self.cubicweb = self.request().create_entity('Project', name=u'cubicweb',
                                         description=u"cubicweb c'est beau")
 
+    def tearDown(self):
+        CubicWebTC.tearDown(self)
+        for sessionid in list(self.repo._sessions):
+            self.repo.close(sessionid)
+
 
 class SecurityTC(TrackerTCMixIn, CubicWebTC):
     repo_config = BaseApptestConfiguration('data')
@@ -85,16 +92,15 @@ class SecurityTC(TrackerTCMixIn, CubicWebTC):
         self.__cnxs = {'admin': self.cnx}
         self.create_user(self.session, 'stduser')
         self.create_user(self.session, 'staffuser', groups=('users', 'staff',))
-        self.cubicweb = security_tc_init_project(self, 'cubicweb', user_prefix='prj1')
-        self.project2 = security_tc_init_project(self, 'project2', user_prefix='prj2')
+        self.cubicweb = security_tc_init_project(self, self.session, 'cubicweb', user_prefix='prj1')
+        self.project2 = security_tc_init_project(self, self.session, 'project2', user_prefix='prj2')
+        self.commit()
         self.maxeid = self.execute('Any MAX(X)')[0][0]
-        cachedperms = self.execute('Any UL, PN WHERE U has_group_permission P, U login UL, P label PN')
-        self.assertEqual(len(cachedperms), 4)
-        self.assertDictEqual(dict(cachedperms),
-                          {'prj1developer': 'cubicwebdevelopers',
-                           'prj1client':    'cubicwebclients',
-                           'prj2developer': 'project2developers',
-                           'prj2client':    'project2clients'})
+
+    def tearDown(self):
+        CubicWebTC.tearDown(self)
+        for sessionid in list(self.repo._sessions):
+            self.repo.close(sessionid)
 
     def mylogin(self, user, **kwargs):
         if not user in self.__cnxs:
@@ -246,6 +252,8 @@ cubicweb-password=gingkow''')]:
         for source in self.repo.sources[1:]:
             self.repo.remove_source(source.uri)
         CubicWebTC.tearDown(self)
+        for sessionid in list(self.repo._sessions):
+            self.repo.close(sessionid)
 
     def extid2eid(self, extid, etype):
         return self.repo.extid2eid(self.extern, str(extid), etype, self.session)
