@@ -1,7 +1,7 @@
 """views for Version entities
 
 :organization: Logilab
-:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2012 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -13,8 +13,8 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb import tags
 from cubicweb.schema import display_name
-from cubicweb.selectors import is_instance, score_entity
-from cubicweb.view import StartupView, EntityAdapter
+from cubicweb.predicates import is_instance, score_entity
+from cubicweb.view import EntityView, StartupView, EntityAdapter
 from cubicweb.web import uicfg, component, action
 from cubicweb.web.views import (baseviews, tabs, tableview,
                                 xmlrss, navigation, ibreadcrumbs)
@@ -212,10 +212,17 @@ class VersionOutOfContextView(baseviews.OutOfContextView):
             project = entity.version_of[0]
             self.w(tags.a(project.name, href=project.absolute_url()))
         self.w(u'&nbsp;-&nbsp;')
-        self.w(u'<a href="%s">' % xml_escape(entity.absolute_url()))
-        self.wdata(entity.num)
-        self.wdata(u' [%s]' % self._cw._(entity.cw_adapt_to('IWorkflowable').state))
-        self.w(u'</a>')
+        entity.view('tracker.link_with_status', w=self.w)
+
+
+class VersionStatusView(EntityView):
+    __select__ = is_instance('Version')
+    __regid__ = 'tracker.link_with_status'
+
+    def entity_call(self, entity):
+        self.w(tags.a(entity.num, href=entity.absolute_url()))
+        state = self._cw._(entity.cw_adapt_to('IWorkflowable').state)
+        self.w(u' [%s]' % xml_escape(state))
 
 
 # other views ##################################################################
